@@ -128,6 +128,7 @@ takes an incomplete SQL SELECT statement and massages it to return a DISTINCT re
 sub DistinctCount {
     my $self = shift;
     my $statementref = shift;
+    my $sb = shift;
 
     $$statementref = "SELECT count(*) FROM (SELECT DISTINCT main.id FROM $$statementref )";
 }
@@ -209,6 +210,13 @@ sub ConvertTimezoneFunction {
     return $res;
 }
 
+sub _DateTimeIntervalFunction {
+    my $self = shift;
+    my %args = ( From => undef, To => undef, @_ );
+
+    return "strftime('%s',$args{'To'}) - strftime('%s',$args{'From'})";
+}
+
 1;
 
 __END__
